summaryrefslogtreecommitdiff
path: root/src/core/common/RttiBuilder.hpp
diff options
context:
space:
mode:
authorAndreas Stöckel <astoecke@techfak.uni-bielefeld.de>2015-01-18 18:41:30 +0100
committerAndreas Stöckel <astoecke@techfak.uni-bielefeld.de>2015-01-18 18:41:30 +0100
commit66382c62af1be515deff66d51dba7f27e5fe4937 (patch)
treecdd661a560ef1f766889d661d8c7561d18bfbabb /src/core/common/RttiBuilder.hpp
parent7d788f2dce18c3ba6f11f7f032d35fef2e5fa9d4 (diff)
Renamed RttiType to Rtti
Diffstat (limited to 'src/core/common/RttiBuilder.hpp')
-rw-r--r--src/core/common/RttiBuilder.hpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/core/common/RttiBuilder.hpp b/src/core/common/RttiBuilder.hpp
index 4b27058..442f358 100644
--- a/src/core/common/RttiBuilder.hpp
+++ b/src/core/common/RttiBuilder.hpp
@@ -45,13 +45,13 @@ class RttiBuilder : public RttiBuilderBase {
public:
/**
* Default constructor, initializes the name of the type described by the
- * RttiTypeSet with "unknown".
+ * RttiSet with "unknown".
*/
RttiBuilder() : RttiBuilderBase(typeid(T)){};
/**
* Default constructor, initializes the name of the type described by the
* RttiTypeSet with the given name.
*
* @param name is the initial name of the type described by the type
* builder.
@@ -78,7 +78,7 @@ public:
* @param p is the pointer to the type descriptor that should be added.
* @return a reference to the current RttiBuilder to allow method chaining.
*/
- RttiBuilder<T> &parent(const RttiType *p)
+ RttiBuilder<T> &parent(const Rtti *p)
{
RttiBuilderBase::parent(p);
return *this;
@@ -91,7 +91,7 @@ public:
* @param p is the pointer to the type descriptor that should be added.
* @return a reference to the current RttiBuilder to allow method chaining.
*/
- RttiBuilder<T> &parent(const RttiTypeSet &p)
+ RttiBuilder<T> &parent(const RttiSet &p)
{
RttiBuilderBase::parent(p);
return *this;
@@ -105,7 +105,7 @@ public:
* composition type.
* @return a reference to the current RttiBuilder to allow method chaining.
*/
- RttiBuilder<T> &composedOf(const RttiType *p)
+ RttiBuilder<T> &composedOf(const Rtti *p)
{
RttiBuilderBase::composedOf(p);
return *this;
@@ -119,7 +119,7 @@ public:
* composition type.
* @return a reference to the current RttiBuilder to allow method chaining.
*/
- RttiBuilder<T> &composedOf(const RttiTypeSet &p)
+ RttiBuilder<T> &composedOf(const RttiSet &p)
{
RttiBuilderBase::composedOf(p);
return *this;
@@ -130,7 +130,7 @@ public:
* type descriptor.
*
* @param name is the name of the method. Names must be unique for one
- * RttiType instance. If the name is not unique, an exception is thrown.
+ * Rtti instance. If the name is not unique, an exception is thrown.
* @param function is the function that should be registered.
* @return a reference to the current RttiBuilder to allow method chaining.
*/
@@ -146,7 +146,7 @@ public:
* for this RTTI type descriptor.
*
* @param name is the name of the property. Names must be unique for one
- * RttiType instance. If the property is not unique, an exception is thrown.
+ * Rtti instance. If the property is not unique, an exception is thrown.
* @param property is the property that should be registered.
* @return a reference to the current RttiBuilder to allow method chaining.
*/
@@ -161,7 +161,7 @@ public:
* Registers a method for this RTTI type descriptor.
*
* @param name is the name of the method. Names must be unique for one
- * RttiType instance. If the name is not unique, an exception is thrown.
+ * Rtti instance. If the name is not unique, an exception is thrown.
* @param method is the function that should be registered.
* @return a reference to the current RttiBuilder to allow method chaining.
*/
@@ -174,7 +174,7 @@ public:
* Registers a method for this RTTI type descriptor.
*
* @param name is the name of the method. Names must be unique for one
- * RttiType instance. If the name is not unique, an exception is thrown.
+ * Rtti instance. If the name is not unique, an exception is thrown.
* @param method is the function that should be registered.
* @return a reference to the current RttiBuilder to allow method chaining.
*/
@@ -188,7 +188,7 @@ public:
* Registers a property for this RTTI type descriptor.
*
* @param name is the name of the property. Names must be unique for one
- * RttiType instance. If the property is not unique, an exception is thrown.
+ * Rtti instance. If the property is not unique, an exception is thrown.
* @param property is the property that should be registered.
* @return a reference to the current RttiBuilder to allow method chaining.
*/
@@ -45,13 +45,13 @@ class RttiBuilder : public RttiBuilderBase {
/**
* Default constructor, initializes the name of the type described by the
- * RttiTypeSet with the given name.
+ * RttiSet with the given name.
*
* @param name is the initial name of the type described by the type